==> jc-1.4.0.tar.gz: java/util/zip/DeflaterConstants.h <==
// abstract interface java.util.zip.DeflaterConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2971d0a046066ef5 java_util_zip_DeflaterConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_DeflaterConstants_H_
#define _JC_java_util_zip_DeflaterConstants_H_

// Typedefs
typedef struct _jc_java_util_zip_DeflaterConstants$fields_struct	_jc_java_util_zip_DeflaterConstants$fields_struct;
typedef const struct _jc_java_util_zip_DeflaterConstants$vtype	_jc_java_util_zip_DeflaterConstants$vtype;

// Class fields structure
struct _jc_java_util_zip_DeflaterConstants$fields_struct {
	_jc_int_array	*COMPR__5fFUNC;
	_jc_int_array	*GOOD__5fLENGTH;
	_jc_int_array	*MAX__5fCHAIN;
	_jc_int_array	*MAX__5fLAZY;
	_jc_int_array	*NICE__5fLENGTH;
	jint	DEFAULT__5fMEM__5fLEVEL;
	jint	DEFLATE__5fFAST;
	jint	DEFLATE__5fSLOW;
	jint	DEFLATE__5fSTORED;
	jint	DYN__5fTREES;
	jint	HASH__5fBITS;
	jint	HASH__5fMASK;
	jint	HASH__5fSHIFT;
	jint	HASH__5fSIZE;
	jint	MAX__5fBLOCK__5fSIZE;
	jint	MAX__5fDIST;
	jint	MAX__5fMATCH;
	jint	MAX__5fWBITS;
	jint	MIN__5fLOOKAHEAD;
	jint	MIN__5fMATCH;
	jint	PENDING__5fBUF__5fSIZE;
	jint	PRESET__5fDICT;
	jint	STATIC__5fTREES;
	jint	STORED__5fBLOCK;
	jint	WMASK;
	jint	WSIZE;
	jboolean	DEBUGGING;
};
extern _jc_java_util_zip_DeflaterConstants$fields_struct _jc_java_util_zip_DeflaterConstants$class_fields;

// Static methods
extern void _jc_java_util_zip_DeflaterConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_java_util_zip_DeflaterConstants$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_java_util_zip_DeflaterConstants$vtype _jc_java_util_zip_DeflaterConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_DeflaterConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_DeflaterConstants$class_object;

#endif	/* _JC_java_util_zip_DeflaterConstants_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/DeflaterConstants.h <==
// abstract interface java.util.zip.DeflaterConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2971d0a046066ef5 java_util_zip_DeflaterConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_DeflaterConstants_H_
#define _JC_java_util_zip_DeflaterConstants_H_

// Typedefs
typedef struct _jc_java_util_zip_DeflaterConstants$fields_struct	_jc_java_util_zip_DeflaterConstants$fields_struct;
typedef const struct _jc_java_util_zip_DeflaterConstants$vtype	_jc_java_util_zip_DeflaterConstants$vtype;

// Class fields structure
struct _jc_java_util_zip_DeflaterConstants$fields_struct {
	_jc_int_array	*COMPR__5fFUNC;
	_jc_int_array	*GOOD__5fLENGTH;
	_jc_int_array	*MAX__5fCHAIN;
	_jc_int_array	*MAX__5fLAZY;
	_jc_int_array	*NICE__5fLENGTH;
	jint	DEFAULT__5fMEM__5fLEVEL;
	jint	DEFLATE__5fFAST;
	jint	DEFLATE__5fSLOW;
	jint	DEFLATE__5fSTORED;
	jint	DYN__5fTREES;
	jint	HASH__5fBITS;
	jint	HASH__5fMASK;
	jint	HASH__5fSHIFT;
	jint	HASH__5fSIZE;
	jint	MAX__5fBLOCK__5fSIZE;
	jint	MAX__5fDIST;
	jint	MAX__5fMATCH;
	jint	MAX__5fWBITS;
	jint	MIN__5fLOOKAHEAD;
	jint	MIN__5fMATCH;
	jint	PENDING__5fBUF__5fSIZE;
	jint	PRESET__5fDICT;
	jint	STATIC__5fTREES;
	jint	STORED__5fBLOCK;
	jint	WMASK;
	jint	WSIZE;
	jboolean	DEBUGGING;
};
extern _jc_java_util_zip_DeflaterConstants$fields_struct _jc_java_util_zip_DeflaterConstants$class_fields;

// Static methods
extern void _jc_java_util_zip_DeflaterConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_java_util_zip_DeflaterConstants$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_java_util_zip_DeflaterConstants$vtype _jc_java_util_zip_DeflaterConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_DeflaterConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_DeflaterConstants$class_object;

#endif	/* _JC_java_util_zip_DeflaterConstants_H_ */
